Function jaro_winkler
fn jaro_winkler(a: &str, b: &str) -> f64
Like Jaro but gives a boost to strings that have a common prefix.
use jaro_winkler;
assert!;
jaro_winklerfn jaro_winkler(a: &str, b: &str) -> f64
Like Jaro but gives a boost to strings that have a common prefix.
use jaro_winkler;
assert!;