Function levenshtein
fn levenshtein(a: &str, b: &str) -> usize
Calculates the minimum number of insertions, deletions, and substitutions required to change one string into the other.
use levenshtein;
assert_eq!;
levenshteinfn levenshtein(a: &str, b: &str) -> usize
Calculates the minimum number of insertions, deletions, and substitutions required to change one string into the other.
use levenshtein;
assert_eq!;