Function hamming
fn hamming(a: &str, b: &str) -> HammingResult
Calculates the number of positions in the two strings where the characters differ. Returns an error if the strings have different lengths.
use ;
assert_eq!;
assert_eq!;